### This is a testing module to make sure things are running smoothly as I setup this function on pip

# Imports
import datetime
import timedelta

### Methods
def print_stats():
    # My Name
    my_name = "Myles Thomas"
    print(f"My name is {my_name}. \n")

    # My Birthday
    my_birthday_date = datetime.date(year=1998, month=2, day=23)
    print(f"My Birthday was on this date: {my_birthday_date}. \n")

    # Current Date
    current_date = datetime.date.today()
    print(f"The current date today is: {current_date}. \n")

    # How long I have been alive
    difference_timedelta = abs(current_date - my_birthday_date)
    time_alive_days_int = difference_timedelta.days
    time_alive_years_int = int(time_alive_days_int / 365) # round down closer to 0 
    print(f"I have been alive for: {time_alive_years_int} years (~{time_alive_days_int} days). \n")

    # Current Age
    current_age_int = int(time_alive_years_int) # round down closer to 0 
    print(f"My current age is {current_age_int}. \n")

    # How many days away I am from my Age + 1 birthday
    next_age_int = current_age_int + 1
    next_birthday_date = datetime.date(year=my_birthday_date.year + next_age_int, month=my_birthday_date.month, day=my_birthday_date.day)
    difference_timedelta = abs(current_date - next_birthday_date)
    days_until_birthday_int = difference_timedelta.days
    print(f"I am {days_until_birthday_int} days away from turning {next_age_int}, which will take place on {next_birthday_date}! \n")

    # End
    print("Until next time! \n")


def columns_janitor(old_col_names):
    """
    input:    list
    output:   list
    """
    new_col_names_list = []
    for col_name in old_col_names:
        # strip whitespace
        col_name_stripped = col_name.strip()
        # make lowercase
        col_name_stripped_and_lower = col_name_stripped.lower()
        # remove weird characters
        new_col_name = "".join(
            item for item in str(col_name_stripped_and_lower) if item.isalnum() or "_" in item
        )
        # make sure there are 0 instances of 2 _'s next to each other
        while "__" in new_col_name:
            new_col_name = new_col_name.replace("__", "_")
        # make sure the column name does not lead or end with _
        while new_col_name[0] == "_":
            new_col_name = new_col_name[1 : len(new_col_name)]
        while new_col_name[len(new_col_name) - 1] == "_":
            new_col_name = new_col_name[0 : len(new_col_name) - 1]
        # append item to list of new columns
        new_col_names_list.append(new_col_name)

    # at end of loop, return the new columns 
    return new_col_names_list


from setuptools import setup, find_packages

VERSION = '0.0.2'
DESCRIPTION = 'My first Python Package!'
LONG_DESCRIPTION = 'This package will have everything I use on a daily basis to make life easier when coding in Python.'

author_name = "Myles Thomas"
author_email = "mylescgthomas@gmail.com"

setup(
    name="mcgtpy",
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author=author_name,
    author_email=author_email,
    license='MIT',
    packages=find_packages(),
    install_requires=[],
    keywords='conversion',
    classifiers= [
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        'License :: OSI Approved :: MIT License',
        "Programming Language :: Python :: 3",
    ]
)